@@ -1,15 +1,16 @@
-#!/bin/bash -e
+#!/usr/bin/env bash
+set -e
 
 REPORT_FILE=${REPORT_FILE:-coverage.xml}
 
-export PYTHONPATH="${PYTHONPATH}:/var/panoptes/POCS/scripts/testing/coverage"
+# This assumes we are always running in a docker container.
 export COVERAGE_PROCESS_START="/var/panoptes/POCS/setup.cfg"
 
 coverage erase
 
-# Run coverage over the pytest suite
+# Run coverage over the pytest suite.
 echo "Starting tests"
-coverage run "$(command -v pytest)" -x -vv -rfes
+coverage run "$(command -v pytest)"
 
 echo "Combining coverage"
 coverage combine
@@ -17,4 +18,6 @@ coverage combine
 echo "Making XML coverage report at ${REPORT_FILE}"
 coverage xml -o "${REPORT_FILE}"
 
+coverage report --show-missing
+
 exit 0
