@@ -31,7 +31,7 @@ class POCS(PanStateMachine, PanBase):
             class. POCS will call the `initialize` method of the observatory.
         state_machine_file(str): Filename of the state machine to use, defaults to
             'simple_state_table'.
-        simulator(list): A list of the different modules that can run in simulator mode. Possible
+        simulators(list): A list of the different modules that can run in simulator mode. Possible
             modules include: all, mount, camera, weather, night. Defaults to an empty list.
 
     Attributes:
@@ -44,11 +44,16 @@ class POCS(PanStateMachine, PanBase):
             self,
             observatory,
             state_machine_file=None,
+            simulators=None,
             *args, **kwargs):
 
-        # Explicitly call the base classes in the order we want
+        # Explicitly call the base classes in the order we want.
         PanBase.__init__(self, *args, **kwargs)
 
+        if simulators:
+            self.logger.warning(f'Using {simulators=}')
+            self.set_config('simulator', simulators)
+
         assert isinstance(observatory, Observatory)
 
         self.name = self.get_config('name', default='Generic PANOPTES Unit')
@@ -61,26 +66,28 @@ class POCS(PanStateMachine, PanBase):
         self.logger.info(f'Making a POCS state machine from {state_machine_file}')
         PanStateMachine.__init__(self, state_machine_file, **kwargs)
 
-        # Add observatory object, which does the bulk of the work
+        # Add observatory object, which does the bulk of the work.
         self.observatory = observatory
 
         self.is_initialized = False
         self._free_space = None
 
+        self.run_once = kwargs.get('run_once', False)
         self._obs_run_retries = self.get_config('pocs.RETRY_ATTEMPTS', default=3)
+        self.connected = True
+        self.interrupted = False
 
         # We want to call and record the status on a periodic interval.
-        def get_status():
-            while True:
+        def get_periodic_status():
+            while self.connected:
                 status = self.status
-                self.logger.debug(f'Periodic status call: {status!r}')
+                self.logger.trace(f'Periodic status call: {status!r}')
                 self.db.insert_current('status', status)
                 CountdownTimer(self.get_config('status_check_interval', default=60)).sleep()
 
-        self._status_thread = Thread(target=get_status, daemon=True)
+        self._status_thread = Thread(target=get_periodic_status, daemon=True)
         self._status_thread.start()
 
-        self.connected = True
         self.say("Hi there!")
 
     @property
@@ -116,14 +123,6 @@ class POCS(PanStateMachine, PanBase):
     def connected(self, new_value):
         self.set_config('pocs.CONNECTED', new_value)
 
-    @property
-    def keep_running(self):
-        return self.get_config('pocs.KEEP_RUNNING', default=True)
-
-    @keep_running.setter
-    def keep_running(self, new_value):
-        self.set_config('pocs.KEEP_RUNNING', new_value)
-
     @property
     def do_states(self):
         return self.get_config('pocs.DO_STATES', default=True)
@@ -132,8 +131,30 @@ class POCS(PanStateMachine, PanBase):
     def do_states(self, new_value):
         self.set_config('pocs.DO_STATES', new_value)
 
+    @property
+    def keep_running(self):
+        """If POCS should keep running.
+
+        Currently reads:
+
+        * `connected`
+        * `do_states`
+        * `observatory.can_observe`
+
+        Returns:
+            bool: If POCS should keep running.
+        """
+        return self.connected and self.do_states and self.observatory.can_observe
+
     @property
     def run_once(self):
+        """If POCS should exit the run loop after a single iteration.
+
+        This value reads the `pocs.RUN_ONCE` config value.
+
+        Returns:
+            bool: if machine should stop after single iteration, default False.
+        """
         return self.get_config('pocs.RUN_ONCE', default=False)
 
     @run_once.setter
@@ -172,6 +193,10 @@ class POCS(PanStateMachine, PanBase):
             bool: True if all initialization succeeded, False otherwise.
         """
 
+        if not self.observatory.can_observe:
+            self.say("Looks like we're missing some required hardware.")
+            return False
+
         if not self.is_initialized:
             self.logger.info('*' * 80)
             self.say("Initializing the system! Woohoo!")
@@ -186,6 +211,7 @@ class POCS(PanStateMachine, PanBase):
                 self.power_down()
             else:
                 self.is_initialized = True
+                self.do_states = True
 
         return self.is_initialized
 
@@ -236,14 +262,12 @@ class POCS(PanStateMachine, PanBase):
             # Observatory shut down
             self.observatory.power_down()
 
-            self.keep_running = True
-            self.do_states = True
-            self.is_initialized = False
-            self.interrupted = False
             self.connected = False
 
+            self._status_thread.join(1)
+
             # Clear all the config items.
-            self.logger.info("Power down complete")
+            self.logger.success("Power down complete")
 
     def reset_observing_run(self):
         """Reset an observing run loop. """
@@ -290,8 +314,12 @@ class POCS(PanStateMachine, PanBase):
         # Check weather
         is_safe_values['good_weather'] = self.is_weather_safe()
 
-        # Hard-drive space
-        is_safe_values['free_space'] = self.has_free_space()
+        # Hard-drive space in root
+        is_safe_values['free_space_root'] = self.has_free_space('/')
+
+        # Hard-drive space in images directory.
+        images_dir = self.get_config('directories.images')
+        is_safe_values['free_space_images'] = self.has_free_space(images_dir)
 
         safe = all(is_safe_values.values())
 
@@ -316,6 +344,15 @@ class POCS(PanStateMachine, PanBase):
 
         return safe
 
+    def _in_simulator(self, key):
+        """Checks the config server for the given simulator key value."""
+        with suppress(KeyError):
+            if key in self.get_config('simulator', default=list()):
+                self.logger.debug(f'Using {key} simulator')
+                return True
+
+        return False
+
     def is_dark(self, horizon='observe'):
         """Is it dark
 
@@ -323,7 +360,7 @@ class POCS(PanStateMachine, PanBase):
         entry `location.flat_horizon` by default.
 
         Args:
-            horizon (str, optional): Which horizon to use, 'flat''focus', or
+            horizon (str, optional): Which horizon to use, 'flat', 'focus', or
                 'observe' (default).
 
         Returns:
@@ -334,11 +371,8 @@ class POCS(PanStateMachine, PanBase):
         is_dark = self.observatory.is_dark(horizon=horizon)
         self.logger.debug(f'Observatory is_dark: {is_dark}')
 
-        # Check simulator
-        with suppress(KeyError):
-            if 'night' in self.get_config('simulator', default=[]):
-                self.logger.debug(f'Using night simulator')
-                is_dark = True
+        if self._in_simulator('night'):
+            return True
 
         self.logger.debug(f"Dark Check: {is_dark}")
         return is_dark
@@ -356,18 +390,12 @@ class POCS(PanStateMachine, PanBase):
 
         # Always assume False
         self.logger.debug("Checking weather safety")
-        is_safe = False
 
-        # Check if we are using weather simulator
-        simulator_values = self.get_config('simulator', default=[])
-        if len(simulator_values):
-            self.logger.debug(f'simulator_values: {simulator_values}')
-
-        if 'weather' in simulator_values:
-            self.logger.info("Weather simulator always safe")
+        if self._in_simulator('weather'):
             return True
 
         # Get current weather readings from database
+        is_safe = False
         try:
             record = self.db.get_current('weather')
             if record is None:
@@ -378,12 +406,11 @@ class POCS(PanStateMachine, PanBase):
             timestamp = record['date'].replace(tzinfo=None)  # current_time is timezone naive
             age = (current_time().datetime - timestamp).total_seconds()
 
-            self.logger.debug(f"Weather Safety: {is_safe} [{age:.0f} sec old - {timestamp:%Y-%m-%d %H:%M:%S}]")
+            self.logger.debug(
+                f"Weather Safety: {is_safe} [{age:.0f} sec old - {timestamp:%Y-%m-%d %H:%M:%S}]")
 
-        except (TypeError, KeyError) as e:
-            self.logger.warning(f"No record found in DB: {e!r}")
         except Exception as e:  # pragma: no cover
-            self.logger.error(f"Error checking weather: {e!r}")
+            self.logger.error(f"No weather record in database: {e!r}")
         else:
             if age >= stale:
                 self.logger.warning("Weather record looks stale, marking unsafe.")
@@ -391,10 +418,12 @@ class POCS(PanStateMachine, PanBase):
 
         return is_safe
 
-    def has_free_space(self, required_space=0.25 * u.gigabyte, low_space_percent=1.5):
+    def has_free_space(self, directory=None, required_space=0.25 * u.gigabyte, low_space_percent=1.5):
         """Does hard drive have disk space (>= 0.5 GB).
 
         Args:
+            directory (str, optional): The path to check free space on, the default
+                `None` will check `$PANDIR`.
             required_space (u.gigabyte, optional): Amount of free space required
                 for operation
             low_space_percent (float, optional): Give warning if space is less
@@ -404,8 +433,9 @@ class POCS(PanStateMachine, PanBase):
         Returns:
             bool: True if enough space
         """
+        directory = directory or os.getenv('PANDIR')
         req_space = required_space.to(u.gigabyte)
-        self._free_space = get_free_space()
+        self._free_space = get_free_space(directory=directory)
 
         space_is_low = self._free_space.value <= (req_space.value * low_space_percent)
 
@@ -413,9 +443,9 @@ class POCS(PanStateMachine, PanBase):
         has_space = bool(self._free_space.value >= req_space.value)
 
         if not has_space:
-            self.logger.error(f'No disk space: Free {self._free_space:.02f}\tReq: {req_space:.02f}')
-        elif space_is_low:
-            self.logger.warning(f'Low disk space: Free {self._free_space:.02f}\tReq: {req_space:.02f}')
+            self.logger.error(f'No disk space for {directory=}: Free {self._free_space:.02f}\t {req_space=:.02f}')
+        elif space_is_low:  # pragma: no cover
+            self.logger.warning(f'Low disk space for {directory=}: Free {self._free_space:.02f}\t {req_space=:.02f}')
 
         return has_space
 
@@ -438,11 +468,7 @@ class POCS(PanStateMachine, PanBase):
         self.logger.debug("Checking for AC power")
         has_power = False
 
-        # TODO(wtgee): figure out if we really want to simulate no power
-        # Check if we are using power simulator
-        simulator_values = self.get_config('simulator', default=[])
-        if 'power' in simulator_values:
-            self.logger.debug("AC power simulator always safe")
+        if self._in_simulator('power'):
             return True
 
         # Get current power readings from database
@@ -459,7 +485,8 @@ class POCS(PanStateMachine, PanBase):
             timestamp = record['date'].replace(tzinfo=None)  # current_time is timezone naive
             age = (current_time().datetime - timestamp).total_seconds()
 
-            self.logger.debug(f"Power Safety: {has_power} [{age:.0f} sec old - {timestamp:%Y-%m-%d %H:%M:%S}]")
+            self.logger.debug(
+                f"Power Safety: {has_power} [{age:.0f} sec old - {timestamp:%Y-%m-%d %H:%M:%S}]")
 
         except (TypeError, KeyError) as e:
             self.logger.warning(f"No record found in DB: {e!r}")
@@ -489,7 +516,7 @@ class POCS(PanStateMachine, PanBase):
             delay {float|None} -- Number of seconds to wait. If default `None`, look up value in
                 config, otherwise 2.5 seconds.
         """
-        if delay is None:
+        if delay is None:  # pragma: no cover
             delay = self.get_config('wait_delay', default=2.5)
 
         sleep_timer = CountdownTimer(delay)
@@ -501,36 +528,3 @@ class POCS(PanStateMachine, PanBase):
         is_expired = sleep_timer.expired()
         self.logger.debug(f'Leaving wait timer: expired={is_expired}')
         return is_expired
-
-    ##################################################################################################
-    # Class Methods
-    ##################################################################################################
-
-    @classmethod
-    def check_environment(cls):
-        """ Checks to see if environment is set up correctly
-
-        There are a number of environmental variables that are expected
-        to be set in order for PANOPTES to work correctly. This method just
-        sanity checks our environment and shuts down otherwise.
-
-            PANDIR    Base directory for PANOPTES
-            POCS      Base directory for POCS
-        """
-        if sys.version_info[:2] < (3, 0):  # pragma: no cover
-            warnings.warn("POCS requires Python 3.x to run")
-
-        pandir = os.getenv('PANDIR')
-        if not os.path.exists(pandir):
-            sys.exit(f"$PANDIR dir does not exist or is empty: {pandir}")
-
-        pocs = os.getenv('POCS')
-        if pocs is None:  # pragma: no cover
-            sys.exit('Please make sure $POCS environment variable is set')
-
-        if not os.path.exists(pocs):
-            sys.exit(f"$POCS directory does not exist or is empty: {pocs}")
-
-        if not os.path.exists(f"{pandir}/logs"):
-            print(f"Creating log dir at {pandir}/logs")
-            os.makedirs(f"{pandir}/logs")
