@@ -11,9 +11,8 @@ def profile():
 
 def test_base_logger(caplog, profile, tmp_path):
     logger = get_logger(log_dir=str(tmp_path),
-                        full_log_file=None,
-                        profile=profile)
+                        full_log_file=None)
     logger.debug('Hello')
-    time.sleep(0.5)
+    time.sleep(1)  # Wait for log to make it there.
     assert caplog.records[-1].message == 'Hello'
     assert caplog.records[-1].levelname == 'DEBUG'
